==> play.it-vv221_2024-01-27.orig.tar.gz: games/play-war-for-the-overworld-expansions.sh <==
#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2022 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# War for the Overworld expansions:
# - The Cynical Imp
# - Founders Theme
# - Kickstarter Theme
# - Underlord Edition
# - Heart of Gold
# - My Pet Dungeon
# - Seasonal Worker Skins
# - The Under Games
###

script_version=20230926.1

PLAYIT_COMPATIBILITY_LEVEL='2.26'

GAME_ID='war-for-the-overworld'
GAME_NAME='War for the Overworld'

EXPANSION_ID_CYNICAL='the-cynical-imp'
EXPANSION_NAME_CYNICAL='The Cynical Imp'

EXPANSION_ID_FOUNDERS='founders-theme'
EXPANSION_NAME_FOUNDERS='Founders Theme'

EXPANSION_ID_KICKSTARTER='kickstarter-theme'
EXPANSION_NAME_KICKSTARTER='Kickstarter Theme'

EXPANSION_ID_UNDERLORD='underlord-edition'
EXPANSION_NAME_UNDERLORD='Underlord Edition'

EXPANSION_ID_HEARTOFGOLD='heart-of-gold'
EXPANSION_NAME_HEARTOFGOLD='Heart of Gold'

EXPANSION_ID_PETDUNGEON='my-pet-dungeon'
EXPANSION_NAME_PETDUNGEON='My Pet Dungeon'

EXPANSION_ID_SEASONALWORKER='seasonal-worker-skins'
EXPANSION_NAME_SEASONALWORKER='Seasonal Worker Skins'

EXPANSION_ID_UNDERGAMES='the-under-games'
EXPANSION_NAME_UNDERGAMES='The Under Games'

# Archives

## The Cynical Imp

ARCHIVE_BASE_CYNICAL_1_NAME='war_for_the_overworld_cynical_imp_charity_v2_1_0f4_55096.sh'
ARCHIVE_BASE_CYNICAL_1_MD5='7941c2d30434ec481056ca668d8901d6'
ARCHIVE_BASE_CYNICAL_1_SIZE='1400'
ARCHIVE_BASE_CYNICAL_1_VERSION='2.1.0f4-gog55096'
ARCHIVE_BASE_CYNICAL_1_URL='http://buy.wftogame.com/charity/'

ARCHIVE_BASE_CYNICAL_0_NAME='war_for_the_overworld_cynical_imp_charity_2_0_7f1_gog_36563.sh'
ARCHIVE_BASE_CYNICAL_0_MD5='301e40e80942c2382dbf892fd3801216'
ARCHIVE_BASE_CYNICAL_0_SIZE='1300'
ARCHIVE_BASE_CYNICAL_0_VERSION='2.0.7f1-gog36563'

## Founders Theme

ARCHIVE_BASE_FOUNDERS_1_NAME='war_for_the_overworld_founders_theme_charity_v2_1_0f4_55096.sh'
ARCHIVE_BASE_FOUNDERS_1_MD5='0313b90d995d5f527feea040995677f7'
ARCHIVE_BASE_FOUNDERS_1_SIZE='1400'
ARCHIVE_BASE_FOUNDERS_1_VERSION='2.1.0f4-gog55096'
ARCHIVE_BASE_FOUNDERS_1_URL='http://buy.wftogame.com/charity/'

ARCHIVE_BASE_FOUNDERS_0_NAME='war_for_the_overworld_founders_theme_charity_2_0_7f1_gog_36563.sh'
ARCHIVE_BASE_FOUNDERS_0_MD5='a8fec55ffb2c9eda265f7f346c8998e6'
ARCHIVE_BASE_FOUNDERS_0_SIZE='1300'
ARCHIVE_BASE_FOUNDERS_0_VERSION='2.0.7f1-gog36563'

## Kickstarter Theme

ARCHIVE_BASE_KICKSTARTER_1_NAME='war_for_the_overworld_kickstarter_theme_charity_v2_1_0f4_55096.sh'
ARCHIVE_BASE_KICKSTARTER_1_MD5='194826ab3072cd5007a8214fe96bc071'
ARCHIVE_BASE_KICKSTARTER_1_SIZE='1400'
ARCHIVE_BASE_KICKSTARTER_1_VERSION='2.1.0f4-gog55096'
ARCHIVE_BASE_KICKSTARTER_1_URL='http://buy.wftogame.com/charity/'

ARCHIVE_BASE_KICKSTARTER_0_NAME='war_for_the_overworld_kickstarter_theme_charity_2_0_7f1_gog_36563.sh'
ARCHIVE_BASE_KICKSTARTER_0_MD5='9ee5fad56ab9dd6676ab4718fa7e5e2e'
ARCHIVE_BASE_KICKSTARTER_0_SIZE='1300'
ARCHIVE_BASE_KICKSTARTER_0_VERSION='2.0.7f1-gog36563'

## Underlord Edition

ARCHIVE_BASE_UNDERLORD_6_NAME='war_for_the_overworld_underlord_edition_upgrade_v2_1_0f4_55096.sh'
ARCHIVE_BASE_UNDERLORD_6_MD5='b2b81108728fe2bbadd51c7897f9269c'
ARCHIVE_BASE_UNDERLORD_6_SIZE='1400'
ARCHIVE_BASE_UNDERLORD_6_VERSION='2.1.0f4-gog55096'
ARCHIVE_BASE_UNDERLORD_6_URL='https://www.gog.com/game/war_for_the_overworld_underlord_edition_upgrade'

ARCHIVE_BASE_UNDERLORD_5_NAME='war_for_the_overworld_underlord_edition_upgrade_2_0_7f1_gog_36563.sh'
ARCHIVE_BASE_UNDERLORD_5_MD5='7cd85994986cf75f9fd81d4be0df82fe'
ARCHIVE_BASE_UNDERLORD_5_SIZE='1300'
ARCHIVE_BASE_UNDERLORD_5_VERSION='2.0.7f1-gog36563'

ARCHIVE_BASE_UNDERLORD_4_NAME='war_for_the_overworld_underlord_edition_upgrade_2_0_7f1_30014.sh'
ARCHIVE_BASE_UNDERLORD_4_MD5='9d67c88dd331703315e9056dc6abb78c'
ARCHIVE_BASE_UNDERLORD_4_SIZE='1300'
ARCHIVE_BASE_UNDERLORD_4_VERSION='2.0.6f1-gog30014'

ARCHIVE_BASE_UNDERLORD_3_NAME='war_for_the_overworld_underlord_edition_upgrade_2_0_6f1_24637.sh'
ARCHIVE_BASE_UNDERLORD_3_MD5='0be12c1160fdba4f180dc3776f1bb21e'
ARCHIVE_BASE_UNDERLORD_3_SIZE='1300'
ARCHIVE_BASE_UNDERLORD_3_VERSION='2.0.6f1-gog24637'

ARCHIVE_BASE_UNDERLORD_2_NAME='war_for_the_overworld_underlord_edition_upgrade_2_0_5_24177.sh'
ARCHIVE_BASE_UNDERLORD_2_MD5='97857939a158c470d04936bc580838c2'
ARCHIVE_BASE_UNDERLORD_2_SIZE='1300'
ARCHIVE_BASE_UNDERLORD_2_VERSION='2.0.5-gog24177'

## Heart of Gold

ARCHIVE_BASE_HEARTOFGOLD_2_NAME='war_for_the_overworld_heart_of_gold_v2_1_0f4_55096.sh'
ARCHIVE_BASE_HEARTOFGOLD_2_MD5='c492a072ab257817abeb7c80f76c1eca'
ARCHIVE_BASE_HEARTOFGOLD_2_SIZE='1400'
ARCHIVE_BASE_HEARTOFGOLD_2_VERSION='2.1.0f4-gog55096'
ARCHIVE_BASE_HEARTOFGOLD_2_URL='https://www.gog.com/game/war_for_the_overworld_heart_of_gold'

ARCHIVE_BASE_HEARTOFGOLD_1_NAME='war_for_the_overworld_heart_of_gold_2_0_7f1_gog_36563.sh'
ARCHIVE_BASE_HEARTOFGOLD_1_MD5='c512019fa698759ba0a96e79fadcb06e'
ARCHIVE_BASE_HEARTOFGOLD_1_SIZE='1400'
ARCHIVE_BASE_HEARTOFGOLD_1_VERSION='2.0.7f1-gog36563'

ARCHIVE_BASE_HEARTOFGOLD_0_NAME='war_for_the_overworld_heart_of_gold_2_0_7f1_30014.sh'
ARCHIVE_BASE_HEARTOFGOLD_0_MD5='2d3555bfea2aafca9ff9e8eb7a970c0d'
ARCHIVE_BASE_HEARTOFGOLD_0_SIZE='1400'
ARCHIVE_BASE_HEARTOFGOLD_0_VERSION='2.0.6f1-gog30014'

## My Pet Dungeon

ARCHIVE_BASE_PETDUNGEON_5_NAME='war_for_the_overworld_my_pet_dungeon_v2_1_0f4_55096.sh'
ARCHIVE_BASE_PETDUNGEON_5_MD5='5aadd3ab719d2fd71df604708b9a29e1'
ARCHIVE_BASE_PETDUNGEON_5_SIZE='1400'
ARCHIVE_BASE_PETDUNGEON_5_VERSION='2.1.0f4-gog55096'
ARCHIVE_BASE_PETDUNGEON_5_URL='https://www.gog.com/game/war_for_the_overworld_my_pet_dungeon'

ARCHIVE_BASE_PETDUNGEON_4_NAME='war_for_the_overworld_my_pet_dungeon_2_0_7f1_gog_36563.sh'
ARCHIVE_BASE_PETDUNGEON_4_MD5='55fd7104b3c3141bc38a2809ae470c92'
ARCHIVE_BASE_PETDUNGEON_4_SIZE='1400'
ARCHIVE_BASE_PETDUNGEON_4_VERSION='2.0.7f1-gog36563'

ARCHIVE_BASE_PETDUNGEON_3_NAME='war_for_the_overworld_my_pet_dungeon_2_0_7f1_30014.sh'
ARCHIVE_BASE_PETDUNGEON_3_MD5='f9cd5f6fbe46d46c98837410f8cbfeee'
ARCHIVE_BASE_PETDUNGEON_3_SIZE='1400'
ARCHIVE_BASE_PETDUNGEON_3_VERSION='2.0.6f1-gog30014'

ARCHIVE_BASE_PETDUNGEON_2_NAME='war_for_the_overworld_my_pet_dungeon_2_0_6f1_24637.sh'
ARCHIVE_BASE_PETDUNGEON_2_MD5='7788aeeee1e9c7cd365eb595e772ff52'
ARCHIVE_BASE_PETDUNGEON_2_SIZE='1400'
ARCHIVE_BASE_PETDUNGEON_2_VERSION='2.0.6f1-gog24637'

ARCHIVE_BASE_PETDUNGEON_1_NAME='war_for_the_overworld_my_pet_dungeon_2_0_5_24177.sh'
ARCHIVE_BASE_PETDUNGEON_1_MD5='eb45d5ee8c699d9ded7d15b82ad1efa3'
ARCHIVE_BASE_PETDUNGEON_1_SIZE='1400'
ARCHIVE_BASE_PETDUNGEON_1_VERSION='2.0.5-gog24177'

## Seasonal Worker Skins

ARCHIVE_BASE_SEASONALWORKER_2_NAME='war_for_the_overworld_seasonal_worker_skins_v2_1_0f4_55096.sh'
ARCHIVE_BASE_SEASONALWORKER_2_MD5='874a21a49ba212ef716e35e0a5b98357'
ARCHIVE_BASE_SEASONALWORKER_2_SIZE='1400'
ARCHIVE_BASE_SEASONALWORKER_2_VERSION='2.1.0f4-gog55096'
ARCHIVE_BASE_SEASONALWORKER_2_URL='https://www.gog.com/game/war_for_the_overworld_worker_skin_collection'

ARCHIVE_BASE_SEASONALWORKER_1_NAME='war_for_the_overworld_seasonal_worker_skins_2_0_7f1_gog_36563.sh'
ARCHIVE_BASE_SEASONALWORKER_1_MD5='ccc02cab316dff3f6a9351217f38f029'
ARCHIVE_BASE_SEASONALWORKER_1_SIZE='1400'
ARCHIVE_BASE_SEASONALWORKER_1_VERSION='2.0.7f1-gog36563'

ARCHIVE_BASE_SEASONALWORKER_0_NAME='war_for_the_overworld_seasonal_worker_skins_2_0_7f1_30014.sh'
ARCHIVE_BASE_SEASONALWORKER_0_MD5='6b4c2c19a901547b1fe9a8a51edab522'
ARCHIVE_BASE_SEASONALWORKER_0_SIZE='1400'
ARCHIVE_BASE_SEASONALWORKER_0_VERSION='2.0.6f1-gog30014'

## The Under Games

ARCHIVE_BASE_UNDERGAMES_1_NAME='war_for_the_overworld_the_under_games_v2_1_0f4_55096.sh'
ARCHIVE_BASE_UNDERGAMES_1_MD5='8c7bdf2299a2cc5795f92e58c94aa57b'
ARCHIVE_BASE_UNDERGAMES_1_SIZE='1400'
ARCHIVE_BASE_UNDERGAMES_1_VERSION='2.1.0f4-gog55096'
ARCHIVE_BASE_UNDERGAMES_1_URL='https://www.gog.com/game/war_for_the_overworld_the_under_games'

ARCHIVE_BASE_UNDERGAMES_0_NAME='war_for_the_overworld_the_under_games_2_0_7f1_gog_36563.sh'
ARCHIVE_BASE_UNDERGAMES_0_MD5='c63ba259c40ab080f697fe03678d287e'
ARCHIVE_BASE_UNDERGAMES_0_SIZE='1400'
ARCHIVE_BASE_UNDERGAMES_0_VERSION='2.0.7f1-gog36563'


CONTENT_PATH_DEFAULT='data/noarch/game'
CONTENT_GAME_MAIN_FILES='
goggame-*.info'

PKG_MAIN_DEPS="$GAME_ID"

# Load common functions

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction_default

# Include game data

content_inclusion_default

# Build packages

packages_generation

# Print instructions

print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0

==> play.it-vv221_2024-06-29.orig.tar.gz: games/play-war-for-the-overworld-expansions.sh <==
#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2022 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# War for the Overworld expansions:
# - The Cynical Imp
# - Founders Theme
# - Kickstarter Theme
# - Underlord Edition
# - Heart of Gold
# - My Pet Dungeon
# - Seasonal Worker Skins
# - The Under Games
###

script_version=20240524.1

PLAYIT_COMPATIBILITY_LEVEL='2.28'

GAME_ID='war-for-the-overworld'
GAME_NAME='War for the Overworld'

EXPANSION_ID_CYNICAL='the-cynical-imp'
EXPANSION_NAME_CYNICAL='The Cynical Imp'

EXPANSION_ID_FOUNDERS='founders-theme'
EXPANSION_NAME_FOUNDERS='Founders Theme'

EXPANSION_ID_KICKSTARTER='kickstarter-theme'
EXPANSION_NAME_KICKSTARTER='Kickstarter Theme'

EXPANSION_ID_UNDERLORD='underlord-edition'
EXPANSION_NAME_UNDERLORD='Underlord Edition'

EXPANSION_ID_HEARTOFGOLD='heart-of-gold'
EXPANSION_NAME_HEARTOFGOLD='Heart of Gold'

EXPANSION_ID_PETDUNGEON='my-pet-dungeon'
EXPANSION_NAME_PETDUNGEON='My Pet Dungeon'

EXPANSION_ID_SEASONALWORKER='seasonal-worker-skins'
EXPANSION_NAME_SEASONALWORKER='Seasonal Worker Skins'

EXPANSION_ID_UNDERGAMES='the-under-games'
EXPANSION_NAME_UNDERGAMES='The Under Games'

# Archives

## The Cynical Imp

ARCHIVE_BASE_CYNICAL_2_NAME='war_for_the_overworld_cynical_imp_charity_v2_1_1_73576.sh'
ARCHIVE_BASE_CYNICAL_2_MD5='a82cbdad5ac4320dac813d5d588af23d'
ARCHIVE_BASE_CYNICAL_2_SIZE='1048'
ARCHIVE_BASE_CYNICAL_2_VERSION='2.1.1-gog73576'
ARCHIVE_BASE_CYNICAL_2_URL='http://buy.wftogame.com/charity/'

ARCHIVE_BASE_CYNICAL_1_NAME='war_for_the_overworld_cynical_imp_charity_v2_1_0f4_55096.sh'
ARCHIVE_BASE_CYNICAL_1_MD5='7941c2d30434ec481056ca668d8901d6'
ARCHIVE_BASE_CYNICAL_1_SIZE='1400'
ARCHIVE_BASE_CYNICAL_1_VERSION='2.1.0f4-gog55096'

ARCHIVE_BASE_CYNICAL_0_NAME='war_for_the_overworld_cynical_imp_charity_2_0_7f1_gog_36563.sh'
ARCHIVE_BASE_CYNICAL_0_MD5='301e40e80942c2382dbf892fd3801216'
ARCHIVE_BASE_CYNICAL_0_SIZE='1300'
ARCHIVE_BASE_CYNICAL_0_VERSION='2.0.7f1-gog36563'

## Founders Theme

ARCHIVE_BASE_FOUNDERS_2_NAME='war_for_the_overworld_founders_theme_charity_v2_1_1_73576.sh'
ARCHIVE_BASE_FOUNDERS_2_MD5='1b12880acd1ddbd352ff8321e6c0b6c8'
ARCHIVE_BASE_FOUNDERS_2_SIZE='1048'
ARCHIVE_BASE_FOUNDERS_2_VERSION='2.1.1-gog73576'
ARCHIVE_BASE_FOUNDERS_2_URL='http://buy.wftogame.com/charity/'

ARCHIVE_BASE_FOUNDERS_1_NAME='war_for_the_overworld_founders_theme_charity_v2_1_0f4_55096.sh'
ARCHIVE_BASE_FOUNDERS_1_MD5='0313b90d995d5f527feea040995677f7'
ARCHIVE_BASE_FOUNDERS_1_SIZE='1400'
ARCHIVE_BASE_FOUNDERS_1_VERSION='2.1.0f4-gog55096'

ARCHIVE_BASE_FOUNDERS_0_NAME='war_for_the_overworld_founders_theme_charity_2_0_7f1_gog_36563.sh'
ARCHIVE_BASE_FOUNDERS_0_MD5='a8fec55ffb2c9eda265f7f346c8998e6'
ARCHIVE_BASE_FOUNDERS_0_SIZE='1300'
ARCHIVE_BASE_FOUNDERS_0_VERSION='2.0.7f1-gog36563'

## Kickstarter Theme

ARCHIVE_BASE_KICKSTARTER_2_NAME='war_for_the_overworld_kickstarter_theme_charity_v2_1_1_73576.sh'
ARCHIVE_BASE_KICKSTARTER_2_MD5='d63028e7708e7bbf167d4ea44db42ab6'
ARCHIVE_BASE_KICKSTARTER_2_SIZE='1048'
ARCHIVE_BASE_KICKSTARTER_2_VERSION='2.1.1-gog73576'
ARCHIVE_BASE_KICKSTARTER_2_URL='http://buy.wftogame.com/charity/'

ARCHIVE_BASE_KICKSTARTER_1_NAME='war_for_the_overworld_kickstarter_theme_charity_v2_1_0f4_55096.sh'
ARCHIVE_BASE_KICKSTARTER_1_MD5='194826ab3072cd5007a8214fe96bc071'
ARCHIVE_BASE_KICKSTARTER_1_SIZE='1400'
ARCHIVE_BASE_KICKSTARTER_1_VERSION='2.1.0f4-gog55096'

ARCHIVE_BASE_KICKSTARTER_0_NAME='war_for_the_overworld_kickstarter_theme_charity_2_0_7f1_gog_36563.sh'
ARCHIVE_BASE_KICKSTARTER_0_MD5='9ee5fad56ab9dd6676ab4718fa7e5e2e'
ARCHIVE_BASE_KICKSTARTER_0_SIZE='1300'
ARCHIVE_BASE_KICKSTARTER_0_VERSION='2.0.7f1-gog36563'

## Underlord Edition

ARCHIVE_BASE_UNDERLORD_7_NAME='war_for_the_overworld_underlord_edition_upgrade_v2_1_1_73576.sh'
ARCHIVE_BASE_UNDERLORD_7_MD5='066e110e2b85ffca512ce8c8d3d67ca3'
ARCHIVE_BASE_UNDERLORD_7_SIZE='1048'
ARCHIVE_BASE_UNDERLORD_7_VERSION='2.1.1-gog73576'
ARCHIVE_BASE_UNDERLORD_7_URL='https://www.gog.com/game/war_for_the_overworld_underlord_edition_upgrade'

ARCHIVE_BASE_UNDERLORD_6_NAME='war_for_the_overworld_underlord_edition_upgrade_v2_1_0f4_55096.sh'
ARCHIVE_BASE_UNDERLORD_6_MD5='b2b81108728fe2bbadd51c7897f9269c'
ARCHIVE_BASE_UNDERLORD_6_SIZE='1400'
ARCHIVE_BASE_UNDERLORD_6_VERSION='2.1.0f4-gog55096'

ARCHIVE_BASE_UNDERLORD_5_NAME='war_for_the_overworld_underlord_edition_upgrade_2_0_7f1_gog_36563.sh'
ARCHIVE_BASE_UNDERLORD_5_MD5='7cd85994986cf75f9fd81d4be0df82fe'
ARCHIVE_BASE_UNDERLORD_5_SIZE='1300'
ARCHIVE_BASE_UNDERLORD_5_VERSION='2.0.7f1-gog36563'

ARCHIVE_BASE_UNDERLORD_4_NAME='war_for_the_overworld_underlord_edition_upgrade_2_0_7f1_30014.sh'
ARCHIVE_BASE_UNDERLORD_4_MD5='9d67c88dd331703315e9056dc6abb78c'
ARCHIVE_BASE_UNDERLORD_4_SIZE='1300'
ARCHIVE_BASE_UNDERLORD_4_VERSION='2.0.6f1-gog30014'

ARCHIVE_BASE_UNDERLORD_3_NAME='war_for_the_overworld_underlord_edition_upgrade_2_0_6f1_24637.sh'
ARCHIVE_BASE_UNDERLORD_3_MD5='0be12c1160fdba4f180dc3776f1bb21e'
ARCHIVE_BASE_UNDERLORD_3_SIZE='1300'
ARCHIVE_BASE_UNDERLORD_3_VERSION='2.0.6f1-gog24637'

ARCHIVE_BASE_UNDERLORD_2_NAME='war_for_the_overworld_underlord_edition_upgrade_2_0_5_24177.sh'
ARCHIVE_BASE_UNDERLORD_2_MD5='97857939a158c470d04936bc580838c2'
ARCHIVE_BASE_UNDERLORD_2_SIZE='1300'
ARCHIVE_BASE_UNDERLORD_2_VERSION='2.0.5-gog24177'

## Heart of Gold

ARCHIVE_BASE_HEARTOFGOLD_3_NAME='war_for_the_overworld_heart_of_gold_v2_1_1_73576.sh'
ARCHIVE_BASE_HEARTOFGOLD_3_MD5='653ab69838583a231b7cc8128286e183'
ARCHIVE_BASE_HEARTOFGOLD_3_SIZE='1048'
ARCHIVE_BASE_HEARTOFGOLD_3_VERSION='2.1.1-gog73576'
ARCHIVE_BASE_HEARTOFGOLD_3_URL='https://www.gog.com/game/war_for_the_overworld_heart_of_gold'

ARCHIVE_BASE_HEARTOFGOLD_2_NAME='war_for_the_overworld_heart_of_gold_v2_1_0f4_55096.sh'
ARCHIVE_BASE_HEARTOFGOLD_2_MD5='c492a072ab257817abeb7c80f76c1eca'
ARCHIVE_BASE_HEARTOFGOLD_2_SIZE='1400'
ARCHIVE_BASE_HEARTOFGOLD_2_VERSION='2.1.0f4-gog55096'

ARCHIVE_BASE_HEARTOFGOLD_1_NAME='war_for_the_overworld_heart_of_gold_2_0_7f1_gog_36563.sh'
ARCHIVE_BASE_HEARTOFGOLD_1_MD5='c512019fa698759ba0a96e79fadcb06e'
ARCHIVE_BASE_HEARTOFGOLD_1_SIZE='1400'
ARCHIVE_BASE_HEARTOFGOLD_1_VERSION='2.0.7f1-gog36563'

ARCHIVE_BASE_HEARTOFGOLD_0_NAME='war_for_the_overworld_heart_of_gold_2_0_7f1_30014.sh'
ARCHIVE_BASE_HEARTOFGOLD_0_MD5='2d3555bfea2aafca9ff9e8eb7a970c0d'
ARCHIVE_BASE_HEARTOFGOLD_0_SIZE='1400'
ARCHIVE_BASE_HEARTOFGOLD_0_VERSION='2.0.6f1-gog30014'

## My Pet Dungeon

ARCHIVE_BASE_PETDUNGEON_6_NAME='war_for_the_overworld_my_pet_dungeon_v2_1_1_73576.sh'
ARCHIVE_BASE_PETDUNGEON_6_MD5='435ec9378fbefad46ad4827d870b84e1'
ARCHIVE_BASE_PETDUNGEON_6_SIZE='1048'
ARCHIVE_BASE_PETDUNGEON_6_VERSION='2.1.1-gog73576'
ARCHIVE_BASE_PETDUNGEON_6_URL='https://www.gog.com/game/war_for_the_overworld_my_pet_dungeon'

ARCHIVE_BASE_PETDUNGEON_5_NAME='war_for_the_overworld_my_pet_dungeon_v2_1_0f4_55096.sh'
ARCHIVE_BASE_PETDUNGEON_5_MD5='5aadd3ab719d2fd71df604708b9a29e1'
ARCHIVE_BASE_PETDUNGEON_5_SIZE='1400'
ARCHIVE_BASE_PETDUNGEON_5_VERSION='2.1.0f4-gog55096'

ARCHIVE_BASE_PETDUNGEON_4_NAME='war_for_the_overworld_my_pet_dungeon_2_0_7f1_gog_36563.sh'
ARCHIVE_BASE_PETDUNGEON_4_MD5='55fd7104b3c3141bc38a2809ae470c92'
ARCHIVE_BASE_PETDUNGEON_4_SIZE='1400'
ARCHIVE_BASE_PETDUNGEON_4_VERSION='2.0.7f1-gog36563'

ARCHIVE_BASE_PETDUNGEON_3_NAME='war_for_the_overworld_my_pet_dungeon_2_0_7f1_30014.sh'
ARCHIVE_BASE_PETDUNGEON_3_MD5='f9cd5f6fbe46d46c98837410f8cbfeee'
ARCHIVE_BASE_PETDUNGEON_3_SIZE='1400'
ARCHIVE_BASE_PETDUNGEON_3_VERSION='2.0.6f1-gog30014'

ARCHIVE_BASE_PETDUNGEON_2_NAME='war_for_the_overworld_my_pet_dungeon_2_0_6f1_24637.sh'
ARCHIVE_BASE_PETDUNGEON_2_MD5='7788aeeee1e9c7cd365eb595e772ff52'
ARCHIVE_BASE_PETDUNGEON_2_SIZE='1400'
ARCHIVE_BASE_PETDUNGEON_2_VERSION='2.0.6f1-gog24637'

ARCHIVE_BASE_PETDUNGEON_1_NAME='war_for_the_overworld_my_pet_dungeon_2_0_5_24177.sh'
ARCHIVE_BASE_PETDUNGEON_1_MD5='eb45d5ee8c699d9ded7d15b82ad1efa3'
ARCHIVE_BASE_PETDUNGEON_1_SIZE='1400'
ARCHIVE_BASE_PETDUNGEON_1_VERSION='2.0.5-gog24177'

## Seasonal Worker Skins

ARCHIVE_BASE_SEASONALWORKER_3_NAME='war_for_the_overworld_seasonal_worker_skins_v2_1_1_73576.sh'
ARCHIVE_BASE_SEASONALWORKER_3_MD5='a74c7dc94c79c37a328a15d9cc4a8385'
ARCHIVE_BASE_SEASONALWORKER_3_SIZE='1048'
ARCHIVE_BASE_SEASONALWORKER_3_VERSION='2.1.1-gog73576'
ARCHIVE_BASE_SEASONALWORKER_3_URL='https://www.gog.com/game/war_for_the_overworld_worker_skin_collection'

ARCHIVE_BASE_SEASONALWORKER_2_NAME='war_for_the_overworld_seasonal_worker_skins_v2_1_0f4_55096.sh'
ARCHIVE_BASE_SEASONALWORKER_2_MD5='874a21a49ba212ef716e35e0a5b98357'
ARCHIVE_BASE_SEASONALWORKER_2_SIZE='1400'
ARCHIVE_BASE_SEASONALWORKER_2_VERSION='2.1.0f4-gog55096'

ARCHIVE_BASE_SEASONALWORKER_1_NAME='war_for_the_overworld_seasonal_worker_skins_2_0_7f1_gog_36563.sh'
ARCHIVE_BASE_SEASONALWORKER_1_MD5='ccc02cab316dff3f6a9351217f38f029'
ARCHIVE_BASE_SEASONALWORKER_1_SIZE='1400'
ARCHIVE_BASE_SEASONALWORKER_1_VERSION='2.0.7f1-gog36563'

ARCHIVE_BASE_SEASONALWORKER_0_NAME='war_for_the_overworld_seasonal_worker_skins_2_0_7f1_30014.sh'
ARCHIVE_BASE_SEASONALWORKER_0_MD5='6b4c2c19a901547b1fe9a8a51edab522'
ARCHIVE_BASE_SEASONALWORKER_0_SIZE='1400'
ARCHIVE_BASE_SEASONALWORKER_0_VERSION='2.0.6f1-gog30014'

## The Under Games

ARCHIVE_BASE_UNDERGAMES_2_NAME='war_for_the_overworld_the_under_games_v2_1_1_73576.sh'
ARCHIVE_BASE_UNDERGAMES_2_MD5='820594211c64b3fe94716921c1da3f73'
ARCHIVE_BASE_UNDERGAMES_2_SIZE='1048'
ARCHIVE_BASE_UNDERGAMES_2_VERSION='2.1.1-gog73576'
ARCHIVE_BASE_UNDERGAMES_2_URL='https://www.gog.com/game/war_for_the_overworld_the_under_games'

ARCHIVE_BASE_UNDERGAMES_1_NAME='war_for_the_overworld_the_under_games_v2_1_0f4_55096.sh'
ARCHIVE_BASE_UNDERGAMES_1_MD5='8c7bdf2299a2cc5795f92e58c94aa57b'
ARCHIVE_BASE_UNDERGAMES_1_SIZE='1400'
ARCHIVE_BASE_UNDERGAMES_1_VERSION='2.1.0f4-gog55096'

ARCHIVE_BASE_UNDERGAMES_0_NAME='war_for_the_overworld_the_under_games_2_0_7f1_gog_36563.sh'
ARCHIVE_BASE_UNDERGAMES_0_MD5='c63ba259c40ab080f697fe03678d287e'
ARCHIVE_BASE_UNDERGAMES_0_SIZE='1400'
ARCHIVE_BASE_UNDERGAMES_0_VERSION='2.0.7f1-gog36563'


CONTENT_PATH_DEFAULT='data/noarch/game'
CONTENT_GAME_MAIN_FILES='
goggame-*.info'

PKG_MAIN_DEPS="$GAME_ID"

# Load common functions

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction_default

# Include game data

content_inclusion_default

# Build packages

packages_generation
print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
